function p = getDirection(S, Slen, nodes, edges, path, R)
% getDirection: returns approximate heading of the path
%
% path      vector of nodes
% R         search radius
%
% p         normed heading
%
% Copyright 2012 Daniel Leitner. See license.txt for details.
%

lind = sub2ind(size(S),path(1:end-1),path(2:end)); % linear indices
l_ = full(Slen(lind)); % lengths
lc_= cumsum([0 l_]); % cumulative lengths

if R>lc_(end)
    
    p = nodes(path(end),:) - nodes(path(1),:);
    p = p/norm(p);
    
else
        
    i = find(lc_>R,1,'first');  % find edge where R is reached 
    e = S(path(i-1), path(i));
    R2 = R-lc_(i-1);    
    ep = edges{e};
    
    if ~isequal(ep(1,:),nodes(path(i-1),:)) % edges points shall connect p(i-1) and p(i)
        ep(:,1) = ep(end:-1:1,1);
        ep(:,2) = ep(end:-1:1,2);
        if ~isequal(ep(1,:),nodes(path(i-1),:))
            disp('someting is wrong....');
        end
    end
    
    p_ = ep(2:end,:) - ep(1:end-1,:); % find point in edge where R is reached
    l_ = sqrt( p_(:,1).^2 + p_(:,2).^2 );
    lc_ = cumsum([0, l_']);
    i = find(lc_>R2,1,'first');
        
    p = ep(i-1,:) - nodes(path(1),:);
    p = p/norm(p);
    
end


