function p = getPathPoints(A, Slen, nodes, edges, path, R)
% getPathPoints: returns coordinates of teh path's edges 
%
% A                 adjacency matrix (edges are edge indices)
% Slen              length of the edges 
% nodes             node points
% edges             list of points corresponding to the edge (E,P)
% path              edges path
% R                 length of path
%
% p                 coordinates of teh path's edges 
%
% Copyright 2012 Daniel Leitner. See license.txt for details.
%

lind = sub2ind(size(A),path(1:end-1),path(2:end)); % linear indices
lc_= cumsum(Slen(lind)); % cumulative lengths

p=[];
if lc_(end)<=R % add all points
    
    for i = 1 : length(lind)
        ep=edges{A(lind(i))};
        if ~isequal(ep(1,:),nodes(path(i),:)) % edges points shall connect p(i-1) and p(i)
            ep(:,1) = ep(end:-1:1,1);
            ep(:,2) = ep(end:-1:1,2);
        end
        p=[p;ep];
    end
    
else
    
    N = find(lc_>R,1,'first');
    
    % add all point of these edges
    for i = 1 : N-1
        ep=edges{A(lind(i))};
        if ~isequal(ep(1,:),nodes(path(i),:)) % edges points shall connect p(i) and p(i+1)
            ep(:,1) = ep(end:-1:1,1);
            ep(:,2) = ep(end:-1:1,2);
        end
        p=[p;ep];
    end
    
    % add some points of last edge
    ep=edges{A(lind(N))};
    if ~isequal(ep(1,:),nodes(path(N),:)) % edges points shall connect p(i) and p(i+1)
        ep(:,1) = ep(end:-1:1,1);
        ep(:,2) = ep(end:-1:1,2);
    end
    if N>1
        l = lc_(N-1);
    else
        l = 0;
        p(1,:) = ep(1,:);
    end
    i = 1;
    while l < R && i<=size(ep,1)
        p(end+1,:) = ep(i,:);
        l = l + sqrt(sum((p(end,:)-p(end-1,:)).^2));
        i = i+1;
    end
    
end


